==> webkit2gtk_2.48.1.orig.tar.xz: webkitgtk-2.48.1/Source/WebCore/rendering/style/PositionTryFallback.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ScopedName.h"
#include <wtf/text/AtomString.h>
#include <wtf/text/TextStream.h>

namespace WebCore {

struct PositionTryFallback {
    std::optional<Style::ScopedName> positionTryRuleName;

    enum class Tactic : uint8_t {
        FlipBlock,
        FlipInline,
        FlipStart
    };
    Vector<Tactic> tactics;

    bool operator==(const PositionTryFallback&) const = default;
};

inline TextStream& operator<<(TextStream& ts, const PositionTryFallback& positionTryFallback)
{
    auto separator = ""_s;
    for (auto& tactic : positionTryFallback.tactics) {
        ts << std::exchange(separator, " "_s);
        switch (tactic) {
        case PositionTryFallback::Tactic::FlipBlock:
            ts << "flip-block";
            break;
        case PositionTryFallback::Tactic::FlipInline:
            ts << "flip-inline";
            break;
        case PositionTryFallback::Tactic::FlipStart:
            ts << "flip-start";
            break;
        }
    }
    return ts;
}

inline TextStream& operator<<(TextStream& ts, const Vector<PositionTryFallback>& positionTryFallbacks)
{
    if (positionTryFallbacks.isEmpty()) {
        ts << "none";
        return ts;
    }
    auto separator = ""_s;
    for (auto& item : positionTryFallbacks) {
        ts << std::exchange(separator, ", "_s);
        ts << item;
    }
    return ts;
}

} // namespace WebCore

==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/rendering/style/PositionTryFallback.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ScopedName.h"
#include <wtf/text/AtomString.h>
#include <wtf/text/TextStream.h>

namespace WebCore {

class StyleProperties;

namespace Style {

struct PositionTryFallback {
    std::optional<ScopedName> positionTryRuleName { };

    enum class Tactic : uint8_t {
        FlipBlock,
        FlipInline,
        FlipStart
    };
    Vector<Tactic> tactics { };

    // A position-area fallback is mutually exclusive with the rest.
    RefPtr<const StyleProperties> positionAreaProperties { };

    ~PositionTryFallback();
    bool operator==(const PositionTryFallback&) const;
};

TextStream& operator<<(TextStream&, const PositionTryFallback&);
TextStream& operator<<(TextStream&, const Vector<PositionTryFallback>&);

} // namespace Style
} // namespace WebCore
